@@ -31,7 +31,7 @@ class TestEvent(object):
         d["notes"] = {}
 
         for key in self.Notes.keys():
-            if type(d["notes"][key]) == list:
+            if type(self.Notes[key]) == list:
                 d["notes"][key] = [str(e) for e in self.Notes[key]]
             else:
                 d["notes"][key] = str(e)
